@@ -13,6 +13,14 @@ fn test_ref_version_mismatch() -> Result<()> {
         @r"
     🌈 zizmor v@@VERSION@@
      INFO audit: zizmor: 🌈 completed @@INPUT@@
+    error[unpinned-uses]: unpinned action reference
+      --> @@INPUT@@:19:15
+       |
+    19 |       - uses: actions/setup-node@v3.8.2 # v3.8.2
+       |               ^^^^^^^^^^^^^^^^^^^^^^^^^ action is not pinned to a hash (required by blanket policy)
+       |
+       = note: audit confidence → High
+
     warning[ref-version-mismatch]: detects commit SHAs that don't match their version comment tags
       --> @@INPUT@@:22:77
        |
@@ -24,7 +32,7 @@ fn test_ref_version_mismatch() -> Result<()> {
        = note: audit confidence → High
        = note: this finding has an auto-fix
 
-    2 findings (1 suppressed, 1 fixable): 0 informational, 0 low, 1 medium, 0 high
+    3 findings (1 suppressed, 1 fixable): 0 informational, 0 low, 1 medium, 1 high
     "
     );
 
